@@ -43,6 +43,8 @@ import glob
 
 
 __driver_index = 'https://chromedriver.chromium.org/downloads'
+__filepath = Path(__file__).resolve().parent
+__fspath = os.fspath(__filepath) + '/'
 
 
 class __Option(Options):
@@ -121,7 +123,7 @@ def __updata_driver(my_version, use_os):
         print(f'\033[1;50;32m正在进行driver{version_driver}下载，请稍后……\033[0m')
         url = f"https://chromedriver.storage.googleapis.com/{version_driver}/{my_os}"
         res = requests.get(url)
-        with open(f'driver-{version_driver}.zip', 'wb') as f:
+        with open(f'{__fspath}driver-{version_driver}.zip', 'wb') as f:
             f.write(res.content)
         # Logger.success(f'成功下载chromedriver文件，版本<{version_driver}>')
         print(f'\033[1;50;32m成功下载chromedriver文件，版本<{version_driver}>\033[0m')
@@ -176,7 +178,7 @@ def __move_file(target_path):
     :return:
     """
     try:
-        file_path = Path('chromedriver.exe')
+        file_path = Path(__fspath + 'chromedriver.exe')
         # print(file_path)
         target_path = Path(target_path + '/' + 'chromedriver.exe')
         # print(target_path)
@@ -210,8 +212,8 @@ def __deleta_files():
     删除当前目录所有遗留文件
     :return:
     """
-    exes = glob.glob('*.exe')
-    zips = glob.glob("*.zip")
+    exes = glob.glob(__fspath + '*.exe')
+    zips = glob.glob(__fspath + "*.zip")
     files = exes + zips
     for exe in files:
         Path(exe).unlink(missing_ok=True)
@@ -252,10 +254,10 @@ def driver(*args, **kwargs):
                             raise Exception('当前路径不是指向的一个文件夹，或者路径不存在')
                     version = __updata_driver(chrome_version, option.os_)
                     if version:
-                        __unzip_file(f'driver-{version}.zip')
+                        __unzip_file(f'{__fspath}driver-{version}.zip')
                         __move_file(option.pypath)
-                        Path(f'driver-{chrome_version}.zip').unlink(missing_ok=True)
-                        Path('chromedriver.exe').unlink(missing_ok=True)
+                        Path(f'{__fspath}driver-{chrome_version}.zip').unlink(missing_ok=True)
+                        Path(f'{__fspath}chromedriver.exe').unlink(missing_ok=True)
                     else:
                         raise Exception("未获取到driver版本名称")
                 else:
